=======
geoalgo
=======

geoalgo is a Django GIS Area calculation.

Detailed documentation contact 999 : emiliogoncalves999@gmail.com.

Quick start
-----------

1. Add "geoalgo" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'geoalgo',
    ]